==> ensmallen_2.17.0.orig.tar.xz: ensmallen-2.17.0/include/ensmallen_bits/problems/problems.hpp <==
/**
 * @file problems.hpp
 * @author Ryan Curtin
 *
 * Include each of the test problems for ensmallen.
 */
#ifndef ENSMALLEN_PROBLEMS_PROBLEMS_HPP
#define ENSMALLEN_PROBLEMS_PROBLEMS_HPP

#include "ackley_function.hpp"
#include "aug_lagrangian_test_functions.hpp"
#include "beale_function.hpp"
#include "booth_function.hpp"
#include "bukin_function.hpp"
#include "colville_function.hpp"
#include "cross_in_tray_function.hpp"
#include "drop_wave_function.hpp"
#include "easom_function.hpp"
#include "eggholder_function.hpp"
#include "fonseca_fleming_function.hpp"
#include "fw_test_function.hpp"
#include "generalized_rosenbrock_function.hpp"
#include "goldstein_price_function.hpp"
#include "gradient_descent_test_function.hpp"
#include "himmelblau_function.hpp"
#include "holder_table_function.hpp"
#include "levy_function_n13.hpp"
#include "logistic_regression_function.hpp"
#include "matyas_function.hpp"
#include "mc_cormick_function.hpp"
#include "rastrigin_function.hpp"
#include "rosenbrock_function.hpp"
#include "rosenbrock_wood_function.hpp"
#include "schaffer_function_n1.hpp"
#include "schaffer_function_n2.hpp"
#include "schaffer_function_n4.hpp"
#include "schwefel_function.hpp"
#include "sgd_test_function.hpp"
#include "softmax_regression_function.hpp"
#include "sparse_test_function.hpp"
#include "sphere_function.hpp"
#include "styblinski_tang_function.hpp"
#include "three_hump_camel_function.hpp"
#include "wood_function.hpp"
#include "zdt/zdt1_function.hpp"
#include "zdt/zdt2_function.hpp"
#include "zdt/zdt3_function.hpp"
#include "zdt/zdt4_function.hpp"
#include "zdt/zdt6_function.hpp"

#endif

==> ensmallen_2.22.1.orig.tar.xz: ensmallen-2.22.1/include/ensmallen_bits/problems/problems.hpp <==
/**
 * @file problems.hpp
 * @author Ryan Curtin
 *
 * Include each of the test problems for ensmallen.
 */
#ifndef ENSMALLEN_PROBLEMS_PROBLEMS_HPP
#define ENSMALLEN_PROBLEMS_PROBLEMS_HPP

#include "ackley_function.hpp"
#include "aug_lagrangian_test_functions.hpp"
#include "beale_function.hpp"
#include "booth_function.hpp"
#include "bukin_function.hpp"
#include "colville_function.hpp"
#include "cross_in_tray_function.hpp"
#include "drop_wave_function.hpp"
#include "easom_function.hpp"
#include "eggholder_function.hpp"
#include "fonseca_fleming_function.hpp"
#include "fw_test_function.hpp"
#include "generalized_rosenbrock_function.hpp"
#include "goldstein_price_function.hpp"
#include "gradient_descent_test_function.hpp"
#include "himmelblau_function.hpp"
#include "holder_table_function.hpp"
#include "levy_function_n13.hpp"
#include "logistic_regression_function.hpp"
#include "matyas_function.hpp"
#include "mc_cormick_function.hpp"
#include "rastrigin_function.hpp"
#include "rosenbrock_function.hpp"
#include "rosenbrock_wood_function.hpp"
#include "schaffer_function_n1.hpp"
#include "schaffer_function_n2.hpp"
#include "schaffer_function_n4.hpp"
#include "schwefel_function.hpp"
#include "sgd_test_function.hpp"
#include "softmax_regression_function.hpp"
#include "sparse_test_function.hpp"
#include "sphere_function.hpp"
#include "styblinski_tang_function.hpp"
#include "three_hump_camel_function.hpp"
#include "wood_function.hpp"
#include "zdt/zdt1_function.hpp"
#include "zdt/zdt2_function.hpp"
#include "zdt/zdt3_function.hpp"
#include "zdt/zdt4_function.hpp"
#include "zdt/zdt6_function.hpp"
#include "dtlz/dtlz1_function.hpp"
#include "dtlz/dtlz2_function.hpp"
#include "dtlz/dtlz3_function.hpp"
#include "dtlz/dtlz4_function.hpp"
#include "dtlz/dtlz5_function.hpp"
#include "dtlz/dtlz6_function.hpp"
#include "dtlz/dtlz7_function.hpp"
#include "maf/maf1_function.hpp"
#include "maf/maf2_function.hpp"
#include "maf/maf3_function.hpp"
#include "maf/maf4_function.hpp"
#include "maf/maf5_function.hpp"
#include "maf/maf6_function.hpp"

#endif
